@@ -1,4 +1,4 @@
-.densKNearestNeighbour.x <- function(x, k, hx)
+.densKNearestNeighbour.x <- function(x, k, hx, npts)
 {
   output <- .C("RdensKNearestNeighbourX",
     n = as.integer(length(x)),
@@ -13,11 +13,20 @@
     stop("in densKNearestNeighbour.x!", call. = FALSE); return(NA)
   }
 
-  i <- order(output$y)
+  i <- !duplicated(output$x) 
 
-  output$x <- output$x[i]
+  output$x <- output$x[i] 
   output$y <- output$y[i]
-
+  
+  n <- length(output$y)
+  
+  if (n > npts) {
+    i <- sample.int(n, npts, replace = FALSE, prob = NULL)  
+  
+    output$x <- output$x[i]
+    output$y <- output$y[i]
+  }
+  
   rm(list = ls()[!(ls() %in% c("output"))])
 
   return(output)
