@@ -2,7 +2,7 @@ is.error <- function(Zt, Zp) {
   error <- array(data = 0, dim = length(Zp))
 
   if (length(Zt) != 0) {
-    zt <- as.numeric(levels(Zt))
+    zt <- as.numeric(names(sort(table(Zt), decreasing = TRUE)))
     zp <- as.numeric(levels(Zp))
 
     for (i in 1:length(zt)) {
@@ -11,7 +11,7 @@ is.error <- function(Zt, Zp) {
 
       j <- as.numeric(names(sort(table(Zpi), decreasing = TRUE)))
 
-      k <- which(j %in% zp == TRUE)
+      k <- which(j %in% zp)
 
       if (length(k) == 0) {
         error[which(Zt == zt[i])] = 1
